import setuptools

setuptools.setup(
    name="weather-map-query",
    version="1.0.1",
    author="Rahul",
    url="https://pypi.org",
    author_email="rchouhan791@gmail.com",
    description="For learning purpose and testing",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>3.5'
)